@@ -21,7 +21,7 @@ def create():
     create pandas dataframe from postgres database
     """
     raw_df = connect_to_db()
-    raw_df.to_pickle('/Users/tovahallas/projects/gc-overrides/raw_data/raw_df.pkl')
+    raw_df.to_pickle('/Users/tovahallas/projects/ml_missions/raw_data/raw_df.pkl')
 
 
 if __name__ == '__main__':
