@@ -139,6 +139,8 @@ def extract_non_overrides(df: pd.DataFrame) -> pd.DataFrame:
     :return: df:pd.DataFrame A DataFrame containing only non overrides.
     """
     non_overrides_df = df[(df['transfer_from'] == '') & (df['transfer_to'] == '') & (df['result_id'] != '')]
+    non_overrides_df = non_overrides_df.copy()
+    non_overrides_df.dropna(subset = ['result_id'], inplace=True)
 
     return non_overrides_df
 
@@ -193,8 +195,8 @@ def remove_special_chars(df: pd.DataFrame) -> pd.DataFrame:
     :param df:pd.DataFrame
     :return: df:pd.DataFrame with chained comments in comments column
     """
-    df['chain_comment'] = df['comment'].str.replace('[^\w\s]', '')
-    df['chain_comment'] = df['chain_comment'].str.replace('\W', '')
+    df['chain_comment'] = df['comment'].str.replace('[^\w\s]', '', regex=True)
+    df['chain_comment'] = df['chain_comment'].str.replace('\W', '', regex=True)
 
     return df
 
@@ -289,8 +291,8 @@ def add_label_col(non_overrides_df: pd.DataFrame, overrides_df: pd.DataFrame) ->
     overrides_labeled = overrides_df.copy()
     non_overrides_labeled = non_overrides_df.copy()
 
-    overrides_labeled['flag'] = 1
-    non_overrides_labeled['flag'] = 0
+    overrides_labeled['label'] = 1
+    non_overrides_labeled['label'] = 0
 
     all_cases_df = create_tot_df(overrides_labeled, non_overrides_labeled)
 
@@ -355,19 +357,34 @@ def preprocess_overrides(df: pd.DataFrame) -> pd.DataFrame:
     """
     overrides_df = extract_overrides(df)
     overrides_df = replace_strings_in_comment(overrides_df)
+    # important- for extract df for binary classification we reduce the cases of overrides by clean_overrides_data
     overrides_df = clean_overrides_data(overrides_df)
     overrides_df = show_overrides_history(overrides_df)
 
     return overrides_df
 
 
+def create_features_df_tl(df: pd.DataFrame) -> pd.DataFrame:
+    """
+    extract features for model from the overrides dataframe with most common comments
+    :param df:pd.DataFrame containing only overrides with most common comments
+    :return: features_df:pd.DataFrame containing features for model
+    """
+    features_df = df[['name', 'gender', 'clinical_significance', 'ref', 'alt', 'hg38_start', 'Paternal Gradma',
+                      'amino_a', 'pos_amino', 'amino_b', 'Paternal Gradpa', 'Maternal Gradma', 'Maternal Gradpa',
+                      'chromosome', 'label']]
+    features_df = features_df.sample(frac=1)
+
+    return features_df
+
+
 def create_features_df(df: pd.DataFrame) -> pd.DataFrame:
     """
     extract features for model from the overrides dataframe with most common comments
     :param df:pd.DataFrame containing only overrides with most common comments
     :return: features_df:pd.DataFrame containing features for model
     """
-    features_df = df[['name', 'clinical_significance', 'ref', 'alt', 'hg38_start', 'Paternal Gradma', 'amino_a',
+    features_df = df[['name', 'gender', 'clinical_significance', 'ref', 'alt', 'hg38_start', 'Paternal Gradma', 'amino_a',
                       'pos_amino', 'amino_b', 'Paternal Gradpa', 'Maternal Gradma', 'Maternal Gradpa', 'chromosome']]
 
     return features_df
